function [d, r0, r] = asdf( s, m )
%[d, r0, r] = asdf( s, m )
% Average Squared Difference Function
% Uses fix window length for all time-lags
% Normalized to d=1.0 for orthogonal lags
%
%	s - input segment
%	m - maximum time lag in samples
%
%	d - m+1 length ASDF vector
%	r0 - power of windowed frame
%	r - m+1 length ACF vector
%
%NOTE: m must complete  0 < m+1 < length(s)  constraint

s = s(:);

% auto correlation
col = flipud( s(1:m+1) );
row = s( m+1:end );
r = rtmult( col, row, row );

% power of windowed frame
r0 = r(1) / length( row );

% moving squared sums
col = col.*col;
row = row.*row;
u = ones( size( row ) );
d = rtmult( col, row, u );

% difference function
d = 0.5 * (d + d(1));
d = d - r;

% scaling to normal
sc = 1.0 / max( r(1), eps );
d = d * sc;
r = r * sc;
